#!perl -T
use Test::More;
use Test::Exception;
use ok( 'Locale::CLDR' );
my $locale;

diag( "Testing Locale::CLDR v0.46.0, Perl $], $^X" );
use ok 'Locale::CLDR::Locales::Kn';
use ok 'Locale::CLDR::Locales::Kn::Knda::In';
use ok 'Locale::CLDR::Locales::Kn::Knda';

done_testing();
